#
# spec file for package btop
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           btop
Version:        1.2.5
Release:        bp154.1.20
Summary:        Usage and stats for processor, memory, disks, network and processes
License:        Apache-2.0
Group:          System/Monitoring
URL:            https://github.com/aristocratos/btop
Source:         %{url}/archive/v%{version}.tar.gz#/v%{version}.tar.gz
BuildRequires:  coreutils
%if 0%{?suse_version} < 1550
%define cxxopt CXX=g++-10
BuildRequires:  gcc10-c++
%else
%define cxxopt %{nil}
BuildRequires:  gcc-c++ >= 11
%endif
BuildRequires:  sed

%description
Resource monitor that shows usage and stats for processor, memory, disks, network and processes. C++ version and continuation of bashtop and bpytop.

%prep
%setup -q

%build
%make_build %{cxxopt}

%install
%make_install PREFIX=/usr

%files
/usr/bin/btop
%dir /usr/share/btop
%dir /usr/share/btop/themes
/usr/share/btop/README.md
/usr/share/btop/themes/*.theme
%license LICENSE
%doc CHANGELOG.md

%changelog
* Mon Mar  7 2022 Scott Bradnick <scott.bradnick@suse.com> - 1.2.5
- Update to upstream release 1.2.5:
  * Fixed: Fallback to less accurate UTF8 char count if conversion to
    wstring fails
  * Fixed: Small ui fixes for mem and disks
  * Added: New theme HotPurpleTrafficLight, by @pallebone
  * Fixed: title_left symbol between auto and zero in the net box is
    not displayed, by @mrdotx
  * Fixed: Mouse mappings for net box
* Mon Feb 28 2022 Scott Bradnick <scott.bradnick@suse.com> - 1.2.4
- Update to upstream release 1.2.4:
  * Optimization: Proc::draw()
  * Fixed: Ignore duplicate disks with same mountpoint
  * Changed: Restrict command line for processes to 1000 characters to fix
    utf8 conversion errors
  * Added: add "g" and "G" to vim keys, by @mohi001
* Tue Feb 15 2022 Scott Bradnick <scott.bradnick@suse.com> - 1.2.3
- Update to upstream release 1.2.3:
  * Changed: floating_humanizer() now show fractions when shortened and value
    is < 10
  * Fixed: Process tree not redrawing properly
  * Fixed: string to wstring conversion crash when string is too big
* Mon Feb 14 2022 Scott Bradnick <scott.bradnick@suse.com> - 1.2.2
- Update to upstream release 1.2.2:
  * Changed: Reverted uncolor() back to using regex to fix delay in opening
    menu when compiled with musl
  * Added: Toggle for showing free disk space for privileged or normal users
  * Added: Clarification on signal screen that number can be manually entered
* Fri Feb 11 2022 Scott Bradnick <scott.bradnick@suse.com> - 1.2.1
- Update to upstream release 1.2.1:
  * Added: Arrow only after use of "f" when filtering processes, by @NavigationHazard
  * Fixed: Fx::uncolor not removing all escapes
  * Fixed: Text alignment for popup boxes
  * Fixed: Terminal resize warning getting stuck
  * Removed: Unnecessary counter for atomic_lock
  * Added: Percentage progress to Makefile
  * Fixed: Alignment of columns in proc box when wide UTF8 characters are used
  * Fixed: Battery meter draw fix
* Tue Jan 18 2022 Scott Bradnick <scott.bradnick@suse.com> - 1.2.0
- Update to upstream release 1.2.0:
  * Added: Support for FreeBSD, by @joske and @aristocratos
  * Fixed (again): Account for system rolling over net speeds in Net::collect()
  * Added: Theme gruvbox_material_dark, by @marcoradocchia
  * Added: Option for base 10 bytes/bits
* Wed Dec 29 2021 Scott Bradnick <scott.bradnick@suse.com> - 1.1.4
- Update to upstream release 1.1.4:
  * Fixed: Create dependency files in build directory when compiling, by @stwnt
  * Fixed: fix CPU temp fallback on macOS, by @joske
  * Changed: From rng::sort() to rng::stable_sort() for more stability
  * Fixed: in_avail() can always be zero, by @pg83
* Mon Dec 13 2021 Scott Bradnick <scott.bradnick@suse.com> - 1.1.3
- Update to upstream release 1.1.3:
  * Added: New theme ayu, by @AlphaNecron
  * Added: New theme gruvbox_dark_v2, by @pietryszak
  * Fixed: Macos cpu coretemp for Intel, by @joske
  * Added: New theme OneDark, by @vtmx
  * Fixed: Fixed network graph scale int rollover
  * Fixed: Suspected possibility of very rare stall in Input::clear()
* Sun Nov 28 2021 Scott Bradnick <scott.bradnick@suse.com> - 1.1.2
- Update to upstream release 1.1.2:
  * Fixed: SISEGV on macos Mojave, by @mgradowski
  * Fixed: Small optimizations and fixes to Mem::collect() and Input::get()
  * Fixed: Wrong unit for net_upload and net_download in config menu
  * Fixed: UTF-8 detection on macos
  * Fixed: coretemp iteration due to missing tempX_input, by @KFilipek
  * Fixed: coretemp ordering
* Tue Nov 16 2021 Scott Bradnick <scott.bradnick@suse.com> - 1.1.1
- Update to upstream release 1.1.1:
  * Added: Partial static build (libgcc, libstdc++) for macos
  * Changed: Continuous build macos switched to OSX 11.6 (Big Sur) and partial static build
  * Changed: Release binaries for macos switched to OSX 12 (Monterey) and partial static build
* Mon Nov 15 2021 Scott Bradnick <scott.bradnick@suse.com> - 1.1.0
- Update to upstream release 1.1.0:
  * Added: Support for OSX, by @joske and @aristocratos
* Tue Nov  9 2021 Scott Bradnick <scott.bradnick@suse.com> - 1.0.24
- Update to upstream release 1.0.24:
  * Changed: Collection ordering
  * Fixed: Restore all escape seq mouse modes on exit
  * Fixed: SIGINT not cleaning up on exit
- Update to upstream relaese 1.0.23:
  * Fixed: Config parser missing first value when not including version header
  * Fixed: Vim keys menu lists selection
  * Fixed: Stall when clearing input queue on exit and queue is >1
  * Fixed: Inconsistent behaviour of "q" key in the menus
* Thu Nov  4 2021 Scott Bradnick <scott.bradnick@suse.com> - 1.0.22
- Update to upstream release 1.0.22:
  * Fixed: Bad values for disks and network on 32-bit
* Tue Nov  2 2021 Scott Bradnick <scott.bradnick@suse.com> - 1.0.21
- Update to upstream release 1.0.21:
  * Fixed: Removed extra spaces in cpu name
  * Added: / as alternative bind for filter
  * Fixed: Security issue when running with SUID bit set
* Wed Oct 27 2021 Scott Bradnick <scott.bradnick@suse.com> - 1.0.20
- Update to upstream release 1.0.20:
  * Added: Improved cpu sensor detection for Ryzen Mobile, by @adnanpri
  * Changed: Updated makefile
  * Changed: Regex for Fx::uncolor() changed to string search and replace
  * Changed: Removed all use of regex with dedicated string functions
* Thu Oct 21 2021 Scott Bradnick <scott.bradnick@suse.com> - 1.0.19
- Update to upstream release 1.0.19:
  * Fixed: Makefile now tests compiler flag compatibility
* Tue Oct 19 2021 Scott Bradnick <scott.bradnick@suse.com> - 1.0.18
- Update to upstream release 1.0.18:
  * Fixed: Makefile g++ -dumpmachine failure to get platform on some distros
- Update to upstream release 1.0.17:
  * Changed: Reverted mutexes back to custom atomic bool based locks
  * Added: Static binaries switched to building with musl + more platforms, by @jan-guenter
  * Fixed: Improved battery detection, by @jan-guenter
  * Added: Displayed battery selectable in options menu
  * Fixed: Battery error if non existent battery named is entered
* Mon Oct 18 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.16 ...
* Wed Oct 13 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.15 ...
* Thu Oct  7 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.14 ...
* Sat Oct  2 2021 Stefan Seyfried <seife+obs@b1-systems.com>
- allow to build on 15.3 also
- improve filelist (no more "files listed twice...")
* Wed Sep 29 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.11 ...
* Tue Sep 28 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.10 ...
* Tue Sep 28 2021 Scott Bradnick <scott.bradnick@suse.com>
- Cleaning commented lines and changelog entries from spec file.
* Mon Sep 27 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.9 ...
* Fri Sep 24 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.6 ...
* Thu Sep 23 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.5 ...
* Wed Sep 22 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.4 ...
* Tue Sep 21 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.2 ...
* Mon Sep 20 2021 Scott Bradnick <scott.bradnick@suse.com>
- Initial commit for version 1.0.1 ...
